@@ -63,7 +63,7 @@ typedef struct {
  */
 
 static const char kmblti_magstr[]="cm-blti";
-static const unsigned char kmblti_version = (char)1;
+static const uint8_t kmblti_version = (uint8_t)1;
 static const size_t kmblti_maglen = 7;  /* = strlen(kmblti_magstr) */
 enum {
     kmblti_saltlen = 10,
@@ -71,7 +71,7 @@ enum {
 };
 
 
-static int kmblti_checkversion(unsigned char fversion)
+static int kmblti_checkversion(uint8_t fversion)
 {
     if (fversion > kmblti_version) {
         fprintf(stderr, "Bad keyfile version [%d]\n", (int)fversion);
@@ -82,19 +82,19 @@ static int kmblti_checkversion(unsigned char fversion)
 }
 
 
-static cm_bf_ctxt_t *kmblti_initcipher_v0(const unsigned char *salt,
+static cm_bf_ctxt_t *kmblti_initcipher_v0(const uint8_t *salt,
         const char *pass, size_t passlen, uint32_t iv[2])
     /** Initialize cipher key (for file-format version-0) */
 {   cm_bf_ctxt_t *ctxt;
     cm_sha1_ctxt_t *md;
-    unsigned char *ckey=NULL;
+    uint8_t *ckey = NULL;
     size_t ckeysz;
     int i;
 
     /* Generate cipher key by sha1-hashing password: */
     md = cm_sha1_init();
     for (i=16; i--; ) {
-        cm_sha1_block(md, (const unsigned char*)pass, passlen);
+        cm_sha1_block(md, (const uint8_t*)pass, passlen);
         cm_sha1_block(md, salt, (size_t)kmblti_saltlen);
     }
     iv[0] = md->H[0];
@@ -111,15 +111,15 @@ static cm_bf_ctxt_t *kmblti_initcipher_v0(const unsigned char *salt,
 }
 
 
-static cm_bf_ctxt_t *kmblti_initcipher_v1(const unsigned char *salt,
+static cm_bf_ctxt_t *kmblti_initcipher_v1(const uint8_t *salt,
         const char *pass, size_t passlen, uint32_t iterations, uint32_t iv[2])
     /** Initialize cipher key (for file-format version-1) */
 {   cm_bf_ctxt_t *ctxt;
-    unsigned char *ckey=NULL;
+    uint8_t *ckey = NULL;
     const size_t ckeysz = 56;
 
     cm_pwd_fortify(pass, iterations, salt, (size_t)kmblti_saltlen,
-                    &ckey, ckeysz);
+                   &ckey, ckeysz);
 
     iv[0] = pack_uint32(ckey + 48);
     iv[1] = pack_uint32(ckey + 52);
@@ -193,15 +193,15 @@ static unsigned kmblti_get_properties(const bound_tgtdefn_t *boundtgt)
 
 static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+            uint8_t **key, int *keylen, FILE *fp_key)
     /** Extract key from sha1/blowfish encrypted file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     cm_bf_ctxt_t *ctxt;
     enum { BUFFSZ = 512 };
-    unsigned char *hbuff=NULL, fversion, salt[kmblti_saltlen],
-            *buff=NULL, *bptr;
+    uint8_t *hbuff = NULL, fversion, salt[kmblti_saltlen],
+            *buff = NULL, *bptr;
     uint32_t iv[2], cv[2], pl[2], iterations = kmblti_default_iterations;
-    char *passwd=NULL;
+    char *passwd = NULL;
     uint32_t chksum, chksum0;
     int cnt, rd_errs=0, eflag=ERR_NOERROR;
 
@@ -211,7 +211,7 @@ static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
     if (eflag != ERR_NOERROR) goto bail_out;
 
     /* Read key header: */
-    hbuff = (unsigned char*)malloc((size_t)(kmblti_maglen + 4));
+    hbuff = (uint8_t*)malloc((size_t)(kmblti_maglen + 4));
     hbuff[0] = '\0';
     rd_errs += cm_fread((void*)hbuff, kmblti_maglen, fp_key);
     if (strncmp((const char*)hbuff, kmblti_magstr, kmblti_maglen) != 0) {
@@ -246,7 +246,7 @@ static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
             break;
     }
     cnt = km_aug_keysz((unsigned)*keylen, 8u) / 8;
-    buff = sec_realloc(buff, (size_t)(cnt * 8));
+    buff = (uint8_t*)sec_realloc(buff, (size_t)(cnt * 8));
     rd_errs += cm_fread((void*)buff, (size_t)(8 * cnt), fp_key);
     bptr = buff;
     while (cnt--) {
@@ -262,14 +262,14 @@ static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
         iv[0] = cv[0];
         iv[1] = cv[1];
 
-        bptr[7] = (unsigned char)((pl[0] >> 24) & 0xff);
-        bptr[6] = (unsigned char)((pl[0] >> 16) & 0xff);
-        bptr[5] = (unsigned char)((pl[0] >> 8) & 0xff);
-        bptr[4] = (unsigned char)(pl[0] & 0xff);
-        bptr[3] = (unsigned char)((pl[1] >> 24) & 0xff);
-        bptr[2] = (unsigned char)((pl[1] >> 16) & 0xff);
-        bptr[1] = (unsigned char)((pl[1] >> 8) & 0xff);
-        bptr[0] = (unsigned char)(pl[1] & 0xff);
+        bptr[7] = (uint8_t)((pl[0] >> 24) & 0xff);
+        bptr[6] = (uint8_t)((pl[0] >> 16) & 0xff);
+        bptr[5] = (uint8_t)((pl[0] >> 8) & 0xff);
+        bptr[4] = (uint8_t)(pl[0] & 0xff);
+        bptr[3] = (uint8_t)((pl[1] >> 24) & 0xff);
+        bptr[2] = (uint8_t)((pl[1] >> 16) & 0xff);
+        bptr[1] = (uint8_t)((pl[1] >> 8) & 0xff);
+        bptr[0] = (uint8_t)(pl[1] & 0xff);
 
         bptr += 8;
     }
@@ -293,7 +293,7 @@ static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
     if (keyinfo->maxlen > 0 && *keylen > keyinfo->maxlen) {
         *keylen = keyinfo->maxlen;
     }
-    *key = (unsigned char*)sec_realloc((void*)*key, (size_t)*keylen);
+    *key = (uint8_t*)sec_realloc((void*)*key, (size_t)*keylen);
     memcpy(*key, buff, (size_t)*keylen);
 
     if (rd_errs > 0 || ferror(fp_key) != 0) {
@@ -314,11 +314,11 @@ static int kmblti_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmblti_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
     /** Store key in sha1/blowfish encrypted file */
 {   cm_bf_ctxt_t *ctxt;
-    unsigned char fversion, salt[kmblti_saltlen], hbuff[4],
-                *buff=NULL, *bptr;
+    uint8_t fversion, salt[kmblti_saltlen], hbuff[4],
+            *buff=NULL, *bptr;
     uint32_t iv[2], cv[2], iterations = kmblti_default_iterations;
     char *passwd=NULL;
     size_t buffsz;
@@ -380,14 +380,14 @@ static int kmblti_put_key(bound_tgtdefn_t *boundtgt,
         iv[0] = cv[0];
         iv[1] = cv[1];
 
-        bptr[7] = (unsigned char)((cv[0] >> 24) & 0xff);
-        bptr[6] = (unsigned char)((cv[0] >> 16) & 0xff);
-        bptr[5] = (unsigned char)((cv[0] >> 8) & 0xff);
-        bptr[4] = (unsigned char)(cv[0] & 0xff);
-        bptr[3] = (unsigned char)((cv[1] >> 24) & 0xff);
-        bptr[2] = (unsigned char)((cv[1] >> 16) & 0xff);
-        bptr[1] = (unsigned char)((cv[1] >> 8) & 0xff);
-        bptr[0] = (unsigned char)(cv[1] & 0xff);
+        bptr[7] = (uint8_t)((cv[0] >> 24) & 0xff);
+        bptr[6] = (uint8_t)((cv[0] >> 16) & 0xff);
+        bptr[5] = (uint8_t)((cv[0] >> 8) & 0xff);
+        bptr[4] = (uint8_t)(cv[0] & 0xff);
+        bptr[3] = (uint8_t)((cv[1] >> 24) & 0xff);
+        bptr[2] = (uint8_t)((cv[1] >> 16) & 0xff);
+        bptr[1] = (uint8_t)((cv[1] >> 8) & 0xff);
+        bptr[0] = (uint8_t)(cv[1] & 0xff);
 
         bptr += 8;
     }
@@ -453,8 +453,8 @@ static unsigned kmpswd_get_properties(const bound_tgtdefn_t *boundtgt)
 
 
 static int kmpswd_get_key(bound_tgtdefn_t *boundtgt,
-            const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+                          const km_pw_context_t *pw_ctxt,
+                          uint8_t **key, int *keylen, FILE *fp_key)
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     char *passwd=NULL;
     int eflag=ERR_NOERROR;
@@ -478,7 +478,7 @@ static int kmpswd_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmpswd_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
 {
     /* This operation isn't valid for a pure-password key */
 
