@@ -24,9 +24,6 @@
 #include <config.h>
 
 #include <ctype.h>
-#if HAVE_DLFCN && USE_MODULES
-#  include <dlfcn.h>
-#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -47,12 +44,7 @@
  */
 
 #if HAVE_LIBGCRYPT
-#  if !USE_MODULES || defined(AS_MODULE)
-#    include <gcrypt.h>
-
-#if defined(TESTING) && defined(AS_MODULE)
-cm_testinfo_t *test_ctxtptr;
-#endif
+#  include <gcrypt.h>
 
 
 /*
@@ -79,7 +71,7 @@ enum {
 
 
 static struct kmgcry_mode {
-    char *name;
+    const char *name;
     unsigned mode; } kmgcry_modes[] = {
     { "ecb",    GCRY_CIPHER_MODE_ECB },
     { "cfb",    GCRY_CIPHER_MODE_CFB },
@@ -256,20 +248,20 @@ static int kmgcry_test_getalgos()
 
 typedef void kmgcry_keybuilder_t(gcry_md_hd_t md,
                     int digest, const size_t mdlen,
-                    const unsigned char *salt,
-                    const unsigned char *pass, const size_t passlen,
-                    unsigned char *ckey, const size_t ckeysz,
-                    unsigned char *civ, const size_t civsz);
+                    const uint8_t *salt,
+                    const uint8_t *pass, const size_t passlen,
+                    uint8_t *ckey, const size_t ckeysz,
+                    uint8_t *civ, const size_t civsz);
 
 static void kmgcry_keybuilder(gcry_md_hd_t md_hand,
                     int digest, const size_t mdlen,
-                    const unsigned char *salt,
-                    const unsigned char *pass, const size_t passlen,
-                    unsigned char *ckey, const size_t ckeysz,
-                    unsigned char *civ, const size_t civsz)
+                    const uint8_t *salt,
+                    const uint8_t *pass, const size_t passlen,
+                    uint8_t *ckey, const size_t ckeysz,
+                    uint8_t *civ, const size_t civsz)
     /*! Generate cipher key & IV from password & salt (default variant) */
 {   size_t kpos, ivpos, pos;
-    unsigned char *buff;
+    uint8_t *buff;
 
     kpos = ivpos = 0;
     do {
@@ -296,16 +288,16 @@ static void kmgcry_keybuilder(gcry_md_hd_t md_hand,
 
 static void kmgcryossl_keybuilder(gcry_md_hd_t md_hand,
                     int digest, const size_t mdlen,
-                    const unsigned char *salt,
-                    const unsigned char *pass, const size_t passlen,
-                    unsigned char *ckey, const size_t ckeysz,
-                    unsigned char *civ, const size_t civsz)
+                    const uint8_t *salt,
+                    const uint8_t *pass, const size_t passlen,
+                    uint8_t *ckey, const size_t ckeysz,
+                    uint8_t *civ, const size_t civsz)
     /*! Generate cipher key & IV from password & salt (a la OpenSSL) */
 {   size_t kpos, ivpos, pos;
-    unsigned char *buff, *prev=NULL;
+    uint8_t *buff, *prev=NULL;
     unsigned cnt=0;
 
-    prev = (unsigned char*)sec_realloc(prev, mdlen);
+    prev = (uint8_t*)sec_realloc(prev, mdlen);
 
     kpos = ivpos = 0;
     do {
@@ -336,12 +328,12 @@ static void kmgcryossl_keybuilder(gcry_md_hd_t md_hand,
 
 
 static int kmgcry_initcipher(int cipher, int ciphermode, int digest,
-            const unsigned char *salt, kmgcry_keybuilder_t keybuilder,
+            const uint8_t *salt, kmgcry_keybuilder_t keybuilder,
             const char *pass, size_t passlen, gcry_cipher_hd_t *hd)
     /*! Initialize block cipher from given password, salt & hashing scheme */
 {   gcry_md_hd_t md_hand;
     size_t ckeysz, cblksz, mdlen;
-    unsigned char *ckey=NULL, *civ=NULL;
+    uint8_t *ckey=NULL, *civ=NULL;
     int eflag=ERR_BADALGORITHM;
 
     if (gcry_cipher_open(hd, cipher, ciphermode, 0) != 0) {
@@ -351,9 +343,9 @@ static int kmgcry_initcipher(int cipher, int ciphermode, int digest,
     }
 
     (void)gcry_cipher_algo_info(cipher, GCRYCTL_GET_KEYLEN, NULL, &ckeysz);
-    ckey = (unsigned char*)sec_realloc(ckey, ckeysz);
+    ckey = (uint8_t*)sec_realloc(ckey, ckeysz);
     (void)gcry_cipher_algo_info(cipher, GCRYCTL_GET_BLKLEN, NULL, &cblksz);
-    civ = (unsigned char*)sec_realloc(civ, cblksz);
+    civ = (uint8_t*)sec_realloc(civ, cblksz);
 
     /* generate cipher key & iv by hashing password: */
     if (keybuilder == NULL) keybuilder = kmgcry_keybuilder;
@@ -363,7 +355,7 @@ static int kmgcry_initcipher(int cipher, int ciphermode, int digest,
     }
     mdlen = gcry_md_get_algo_dlen(digest);
     keybuilder(md_hand, digest, mdlen, salt,
-            (const unsigned char*)pass, passlen, ckey, ckeysz, civ, cblksz);
+            (const uint8_t*)pass, passlen, ckey, ckeysz, civ, cblksz);
     gcry_md_close(md_hand);
 
     /* setup cipher initial state: */
@@ -471,18 +463,18 @@ static unsigned kmgcry_get_properties(const bound_tgtdefn_t *boundtgt)
 
 static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+            uint8_t **key, int *keylen, FILE *fp_key)
     /*! Extract key from libgcrypt-encrypted file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
-    unsigned char *hbuff=NULL, salt[kmgcry_saltlen], *buff=NULL, *bptr;
+    uint8_t *hbuff = NULL, salt[kmgcry_saltlen], *buff = NULL, *bptr;
     size_t cblksz;
     uint32_t chksum, chksum0;
     int cnt, rd_errs=0, cipher, ciphermode, digest, eflag=ERR_NOERROR;
 
     *key = NULL; *keylen = 0;
-    hbuff = sec_realloc(hbuff, (kmgcry_maglen + 4));
+    hbuff = (uint8_t*)sec_realloc(hbuff, (kmgcry_maglen + 4));
 
     eflag = kmgcry_get_algos(keyinfo, &cipher, &ciphermode, &digest);
     if (eflag != ERR_NOERROR) goto bail_out;
@@ -520,7 +512,7 @@ static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
                     salt, NULL, passwd, strlen(passwd), &chd);
     if (eflag != ERR_NOERROR) goto bail_out;
     cnt = km_aug_keysz((unsigned)*keylen, (unsigned)cblksz) / cblksz;
-    buff = sec_realloc(buff, cnt * cblksz);
+    buff = (uint8_t*)sec_realloc(buff, cnt * cblksz);
     bptr = buff;
     while (cnt--) {
         rd_errs += cm_fread((void*)bptr, cblksz, fp_key);
@@ -547,7 +539,7 @@ static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
     if (keyinfo->maxlen > 0 && *keylen > keyinfo->maxlen) {
         *keylen = keyinfo->maxlen;
     }
-    *key = (unsigned char*)sec_realloc((void*)*key, (size_t)*keylen);
+    *key = (uint8_t*)sec_realloc((void*)*key, (size_t)*keylen);
     memcpy(*key, buff, (size_t)*keylen);
 
     if (rd_errs > 0 || ferror(fp_key) != 0) {
@@ -568,12 +560,12 @@ static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmgcry_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
     /*! Store key in libgcrypt-encrypted file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
-    unsigned char hbuff[4], salt[kmgcry_saltlen], *buff=NULL, *bptr;
+    uint8_t hbuff[4], salt[kmgcry_saltlen], *buff=NULL, *bptr;
     size_t buffsz, cblksz;
     int cnt, wr_errs = 0, cipher, ciphermode, digest, eflag=ERR_NOERROR;
 
@@ -630,18 +622,18 @@ static int kmgcry_put_key(bound_tgtdefn_t *boundtgt,
 
 static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+            uint8_t **key, int *keylen, FILE *fp_key)
     /*! Extract key from OpenSSL-compatible file via libgcrypt */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
-    unsigned char *hbuff=NULL, salt[kmgcryossl_saltlen], *buff=NULL;
+    uint8_t *hbuff=NULL, salt[kmgcryossl_saltlen], *buff=NULL;
     size_t cblksz, buffsz=0, pos, ofs, idx;
     int kbad=0, cipher, ciphermode, digest,
         rd_errs=0, eflag=ERR_NOERROR;
 
     *key = NULL; *keylen = 0;
-    hbuff = sec_realloc(hbuff, kmgcryossl_maglen);
+    hbuff = (uint8_t*)sec_realloc(hbuff, kmgcryossl_maglen);
 
     eflag = kmgcry_get_algos(keyinfo, &cipher, &ciphermode, &digest);
     if (eflag != ERR_NOERROR) goto bail_out;
@@ -669,7 +661,7 @@ static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
     while (!feof(fp_key)) {
         if ((pos + cblksz) > buffsz) {
             buffsz = (buffsz * 2) + 4 * cblksz;
-            buff = sec_realloc(buff, buffsz);
+            buff = (uint8_t*)sec_realloc(buff, buffsz);
         }
         if (cm_fread((void*)(buff + pos), cblksz, fp_key) != 0) break;
         gcry_cipher_decrypt(chd, (void*)(buff + pos), cblksz, NULL, 0);
@@ -703,7 +695,7 @@ static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
     if (keyinfo->maxlen > 0 && *keylen > keyinfo->maxlen) {
         *keylen = keyinfo->maxlen;
     }
-    *key = (unsigned char*)sec_realloc((void*)*key, (size_t)*keylen);
+    *key = (uint8_t*)sec_realloc((void*)*key, (size_t)*keylen);
     memcpy(*key, buff, (size_t)*keylen);
 
     if (rd_errs > 0 || ferror(fp_key) != 0) {
@@ -724,12 +716,12 @@ static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmgcryossl_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
     /*! Store key in OpenSSL-compatible file via libgcrypt */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
-    char *passwd=NULL;
-    unsigned char salt[kmgcryossl_saltlen], *buff=NULL;
+    char *passwd = NULL;
+    uint8_t salt[kmgcryossl_saltlen], *buff = NULL;
     size_t buffsz, cblksz, pos;
     int wr_errs=0, cipher, ciphermode, digest, eflag=ERR_NOERROR;
 
@@ -749,7 +741,7 @@ static int kmgcryossl_put_key(bound_tgtdefn_t *boundtgt,
 
     /* Pad key-data with end-marker: */
     buffsz = cblksz * ((keylen + cblksz) / cblksz);
-    buff = sec_realloc(buff, buffsz);
+    buff = (uint8_t*)sec_realloc(buff, buffsz);
     memcpy((void*)buff, (const void*)key, (size_t)keylen);
     for (pos=keylen; pos<buffsz; ++pos) buff[pos] = (buffsz - keylen);
 
@@ -786,11 +778,11 @@ static int kmgcryossl_put_key(bound_tgtdefn_t *boundtgt,
 static int kmgcry_test_hash()
 {   gcry_md_hd_t mdcontext;
     int algo;
-    unsigned char *mdval=NULL;
+    uint8_t *mdval = NULL;
     size_t mdlen, i;
     unsigned q;
-    const char *str="noisy\n";
-    const char *hash="7c1c9261fa774475ec1c0d887eaf00c19b0eb218";
+    const char *str = "noisy\n";
+    const char *hash = "7c1c9261fa774475ec1c0d887eaf00c19b0eb218";
 
     CM_TEST_START("libgcrypt hashing");
 
@@ -857,33 +849,18 @@ keymanager_t keymgr_gcry = {
 #endif
 };
 
-#  endif    /* !USE_MODULES || defined(AS_MODULE) */
 #endif  /* HAVE_LIBGCRYPT */
 
 
-#ifndef AS_MODULE
-
-#if defined(TESTING)
-#  define MOD_PATH CM_SRCDIR "/cm-gcry.so"
-#else
-#  define MOD_PATH CM_MODULE_DIR "/cm-gcry.so"
-#endif
-
 keymanager_t *kmgcry_gethandle()
 {
 #if HAVE_LIBGCRYPT
-#  if USE_MODULES
-    KM_GETHANDLE(MOD_PATH, "keymgr_gcry");
-#  else
     return &keymgr_gcry;
-#  endif
 #else
     return NULL;
 #endif
 }
 
-#endif  /* !AS_MODULE */
-
 /**  @} */
 
 /*
