@@ -24,9 +24,6 @@
 #include <config.h>
 
 #include <ctype.h>
-#if HAVE_DLFCN && USE_MODULES
-#  include <dlfcn.h>
-#endif
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -59,18 +56,13 @@ typedef struct {
  */
 
 #if USE_LUKSCOMPAT
-#  if !USE_MODULES || defined(AS_MODULE)
 #    include <gcrypt.h>
 #    include <libcryptsetup.h>
 
-#if defined(TESTING) && defined(AS_MODULE)
-cm_testinfo_t *test_ctxtptr;
-#endif
-
 
 static int kmluks_hdrvalid(FILE *fp_key)
     /* Check whether a valid LUKS header is present */
-{   const unsigned char luks_magic[] = { 'L','U','K','S', 0xba, 0xbe };
+{   const uint8_t luks_magic[] = { 'L','U','K','S', 0xba, 0xbe };
     const size_t magic_len = sizeof(luks_magic);
     char buff[32];
     int flg = 0;
@@ -213,7 +205,7 @@ static unsigned kmluks_get_properties(const bound_tgtdefn_t *boundtgt)
  *  @return The slot associated with the new password.
  */
 int kmluks_change_slot_passwd(struct crypt_device *cd, int keyslot,
-                              const unsigned char *key, const int keylen,
+                              const uint8_t *key, const int keylen,
                               const char *passwd)
 {   const size_t passwdlen = strlen(passwd);
     int new_slot = -1, bckp_slot = -1, r;
@@ -260,7 +252,7 @@ void kmluks_log(int level, const char *msg, void *data)
 
 static int kmluks_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+            uint8_t **key, int *keylen, FILE *fp_key)
     /*! Extract key from LUKS header file */
 {   tgtdefn_t *tgt = boundtgt->tgt;
     char *passwd = NULL, label[256];
@@ -316,7 +308,7 @@ static int kmluks_get_key(bound_tgtdefn_t *boundtgt,
     boundtgt->km_data = (void*)luksor;
 
     /* Take copy of LUKS master-key: */
-    *key = (unsigned char*)sec_realloc((void*)*key, lcs_keylen);
+    *key = (uint8_t*)sec_realloc((void*)*key, lcs_keylen);
     crypt_volume_key_get(luks_ctxt, slot, (char*)*key, &lcs_keylen,
                          passwd, strlen(passwd));
     *keylen = lcs_keylen;
@@ -334,8 +326,8 @@ static int kmluks_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmluks_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
-    /* Store or create key in LUKS header */
+            const uint8_t *key, const int keylen, FILE *fp_key)
+    /** Store or create key in LUKS header */
 {
     const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     char *passwd = NULL, *ciphername = NULL, *ciphermode = NULL;
@@ -484,33 +476,18 @@ keymanager_t keymgr_luks = {
 #endif
 };
 
-#  endif    /* !USE_MODULES || defined(AS_MODULE) */
 #endif  /* USE_LUKSCOMPAT */
 
 
-#ifndef AS_MODULE
-
-#if defined(TESTING)
-#  define MOD_PATH CM_SRCDIR "/cm-luks.so"
-#else
-#  define MOD_PATH CM_MODULE_DIR "/cm-luks.so"
-#endif
-
 keymanager_t *kmluks_gethandle()
 {
 #if USE_LUKSCOMPAT
-#  if USE_MODULES
-    KM_GETHANDLE(MOD_PATH, "keymgr_luks");
-#  else
     return &keymgr_luks;
-#  endif
 #else
     return NULL;
 #endif
 }
 
-#endif  /* !AS_MODULE */
-
 /**  @} */
 
 /*
