@@ -53,8 +53,6 @@
  *  @{ */
 
 
-#ifndef AS_MODULE
-
 keymanager_t *kmblti_gethandle(void);
 keymanager_t *kmgcry_gethandle(void);
 keymanager_t *kmluks_gethandle(void);
@@ -124,7 +122,7 @@ static unsigned kmraw_get_properties(const bound_tgtdefn_t *boundtgt)
 
 static int kmraw_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            unsigned char **key, int *keylen, FILE *fp_key)
+            uint8_t **key, int *keylen, FILE *fp_key)
     /** Extract key from unencrypted (plain) file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     enum { BUFFSZ=512 };
@@ -147,7 +145,7 @@ static int kmraw_get_key(bound_tgtdefn_t *boundtgt,
         if (len == 0) break;
 
         /* Copy new block of data onto end of current key: */
-        *key = (unsigned char*)sec_realloc((void*)*key, (size_t)(*keylen+len));
+        *key = (uint8_t*)sec_realloc((void*)*key, (size_t)(*keylen+len));
         memcpy((void*)(*key + *keylen), (const void*)buff, len);
         *keylen += len;
     }
@@ -167,7 +165,7 @@ static int kmraw_get_key(bound_tgtdefn_t *boundtgt,
 
 static int kmraw_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
     /** Store key in unencrypted (plain) file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     int eflag=ERR_NOERROR;
@@ -194,16 +192,12 @@ static keymanager_t keymgr_raw = {
 #endif
 };
 
-#endif  /* !AS_MODULE */
-
 
 
 /*
  *  ==== Abstract key-management interfaces ====
  */
 
-#ifndef AS_MODULE
-
 static keymanager_t **add_keymgr(keymanager_t **ptr, keymanager_t *km)
     /* Add key-manager interface definition(s) to list of available managers */
 {
@@ -346,8 +340,6 @@ bound_tgtdefn_t *bind_tgtdefn(const tgtdefn_t *tgt)
     return bound;
 }
 
-#endif  /* !AS_MODULE */
-
 
 /*!
  *  Extract the filesystem encryption key for a particular target.
@@ -356,7 +348,7 @@ bound_tgtdefn_t *bind_tgtdefn(const tgtdefn_t *tgt)
  *  in the \ref keymanager_t structure.
  */
 int cm_get_key(bound_tgtdefn_t *boundtgt, const km_pw_context_t *pw_ctxt,
-               unsigned char **key, int *keylen)
+               uint8_t **key, int *keylen)
 {   keyinfo_t *keyinfo = &boundtgt->tgt->key;
     FILE *fp = NULL;
     unsigned props, attempts = 0;
@@ -395,7 +387,7 @@ int cm_get_key(bound_tgtdefn_t *boundtgt, const km_pw_context_t *pw_ctxt,
 
 
 int cm_put_key(bound_tgtdefn_t *boundtgt, const km_pw_context_t *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key)
+            const uint8_t *key, const int keylen, FILE *fp_key)
 {   unsigned props;
     int eflag = ERR_NOERROR;
 
@@ -465,7 +457,7 @@ int km_test_keyrw(void)
     bound_tgtdefn_t *bound=NULL;
     int i, keylen=0, keylen1, eflag;
     char str[256];
-    unsigned char key0[MAXKEY], *key1=NULL;
+    uint8_t key0[MAXKEY], *key1=NULL;
     FILE *fp;
     extern cm_testinfo_t *test_ctxtptr;
 
@@ -567,7 +559,7 @@ int km_archive_keys(void)
         /* Write key to file: */
         fp = fopen(filename, "wb");     /* May need to be "r+b" for LUKS */
         flg |= km->put_key(bound, &pw_ctxt,
-                        (const unsigned char*)km_legacy_key,
+                        (const uint8_t*)km_legacy_key,
                         strlen(km_legacy_key), fp);
         fclose(fp);
 
@@ -588,7 +580,7 @@ int km_test_legacy(void)
     tgtdefn_t *target;
     bound_tgtdefn_t *bound=NULL;
     km_pw_context_t pw_ctxt;
-    unsigned char *key=NULL;
+    uint8_t *key=NULL;
     int idx, n_legacy = 0, keylen, flg;
     char *tokbuff, keyglob[1024];
     const char *basepath;
@@ -681,7 +673,7 @@ int km_test_legacy(void)
  *  ==== Miscellaneous routines ====
  */
 
-size_t mk_key_string(const unsigned char *key, const size_t keylen, char *buff)
+size_t mk_key_string(const uint8_t *key, const size_t keylen, char *buff)
     /** Create text version of crypto key */
 {   size_t i;
 
