@@ -66,12 +66,12 @@ typedef struct keymanager {
     /*! Extract encrypted key from file: */
     int (*get_key)(struct bound_tgtdefn *boundtgt,
                     const struct km_pw_context *pw_ctxt,
-                    unsigned char **key, int *keylen, FILE *fp_key);
+                    uint8_t **key, int *keylen, FILE *fp_key);
 
     /*! Write encrypted key into file: */
     int (*put_key)(struct bound_tgtdefn *boundtgt,
                     const struct km_pw_context *pw_ctxt,
-                    const unsigned char *key, const int keylen, FILE *fp_key);
+                    const uint8_t *key, const int keylen, FILE *fp_key);
 
     /*! Linked-list scaffolding: */
     struct keymanager *next;
@@ -119,11 +119,11 @@ void free_boundtgt(bound_tgtdefn_t *boundtgt);
 unsigned cm_get_keyproperties(const bound_tgtdefn_t *boundtgt);
 int cm_get_key(bound_tgtdefn_t *boundtgt,
             const struct km_pw_context *pw_ctxt,
-            unsigned char **key, int *keylen);
+            uint8_t **key, int *keylen);
 int cm_put_key(bound_tgtdefn_t *boundtgt,
             const struct km_pw_context *pw_ctxt,
-            const unsigned char *key, const int keylen, FILE *fp_key);
-size_t mk_key_string(const unsigned char *key, const size_t keylen,
+            const uint8_t *key, const int keylen, FILE *fp_key);
+size_t mk_key_string(const uint8_t *key, const size_t keylen,
             char *buff);
 
 int sycheck_directory(const char *dirname);
@@ -134,18 +134,6 @@ int cm_mutex_lock(void);
 int cm_mutex_unlock(void);
 
 
-/* loadable keymanager-module helper macro: */
-#define KM_GETHANDLE(MOD_PATH, SYMBOL)                                      \
-    void *dlptr=NULL, *table=NULL;                                          \
-    dlptr = dlopen(MOD_PATH, RTLD_LAZY);                                    \
-    if (dlptr == NULL) {                                                    \
-        fprintf(stderr, "failed to open keymanager-module \"%s\" - %s\n",   \
-                MOD_PATH, dlerror());                                        \
-        return NULL;                                                        \
-    }                                                                       \
-    table = dlsym(dlptr, SYMBOL);                                           \
-    return (keymanager_t*)table;
-
 /**  @} */
 
 #endif  /* _ARMOUR_H */
