@@ -369,7 +369,7 @@ void cm_bf_decipher(const cm_bf_ctxt_t *ctxt, uint32_t *xl, uint32_t *xr)
 }
 
 
-cm_bf_ctxt_t *cm_bf_init(unsigned char *key, size_t keybytes)
+cm_bf_ctxt_t *cm_bf_init(uint8_t *key, size_t keybytes)
 {   cm_bf_ctxt_t *ctxt;
     uint32_t data, datal, datar;
     size_t i, j, k;
@@ -426,7 +426,7 @@ void cm_bf_free(cm_bf_ctxt_t *ctxt)
 int bf_test_blowfish()
     /* Check Blowfish encryption against known test-vectors */
 {   struct tvec {
-        char *key;
+        const char *key;
         uint32_t in0, in1;
         uint32_t out0, out1; }
     tvecs[] = {
@@ -447,7 +447,7 @@ int bf_test_blowfish()
 
     idx = 0;
     while (tvecs[idx].key != NULL) {
-        ctxt = cm_bf_init((unsigned char*)tvecs[idx].key,
+        ctxt = cm_bf_init((uint8_t*)tvecs[idx].key,
                             strlen(tvecs[idx].key));
         vals[0] = tvecs[idx].in0;
         vals[1] = tvecs[idx].in1;
