@@ -372,7 +372,7 @@ static int do_sysboot_updown(int booting, const tgtdefn_t *tgttable,
 static int do_devsetup(const km_pw_context_t *pw_ctxt,
                        bound_tgtdefn_t *boundtgt, char **mntdev)
 {   enum { BUFFMIN=1024 };
-    unsigned char *key = NULL;
+    uint8_t *key = NULL;
     int buffpos, blklen, readonly, isloop = 0, killloop = 0,
         keylen = 0, eflag = ERR_NOERROR;
     int64_t devlen = 0, fslen = 0;
@@ -420,7 +420,7 @@ static int do_devsetup(const km_pw_context_t *pw_ctxt,
 
     /* Setup device-mapper crypt table (CIPHER KEY IV_OFFSET DEV START): */
     dpsize = 2 * keylen + BUFFMIN;
-    dmparams = sec_realloc(dmparams, dpsize);
+    dmparams = (char*)sec_realloc(dmparams, dpsize);
     buffpos = snprintf(dmparams, dpsize, "%s ",
                         (tgt->cipher != NULL ?  tgt->cipher
                                              : CM_DEFAULT_CIPHER));
@@ -745,7 +745,7 @@ static int do_swapoff(const bound_tgtdefn_t *boundtgt)
  */
 static int do_passwd(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt)
 {   tgtdefn_t *tgt = boundtgt->tgt;
-    unsigned char *key = NULL;
+    uint8_t *key = NULL;
     unsigned keyprops;
     int keylen = 0, eflag = ERR_NOERROR;
     char *newfname = NULL, *oldfname = NULL;
@@ -834,16 +834,16 @@ static int do_passwd(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt)
  */
 static int do_keygen(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt,
                     const char *params, int reuse, const tgtdefn_t *tgttable)
-{   unsigned char *key=NULL;
+{   uint8_t *key = NULL;
     unsigned keyprops;
-    int keylen=0, fileexists=0, eflag=ERR_NOERROR;
-    char *newfname=NULL;
+    int keylen = 0, fileexists = 0, eflag = ERR_NOERROR;
+    char *newfname = NULL;
     tgtdefn_t *tgt = boundtgt->tgt;
-    const tgtdefn_t *parent=NULL;
-    bound_tgtdefn_t *boundparent=NULL;
+    const tgtdefn_t *parent = NULL;
+    bound_tgtdefn_t *boundparent = NULL;
     size_t sz;
     struct stat sbuff;
-    FILE *fp=NULL;
+    FILE *fp = NULL;
     const unsigned mask_fmtfxd = KM_PROP_FIXEDLOC | KM_PROP_FORMATTED;
 
     if (params != NULL) {
@@ -880,7 +880,7 @@ static int do_keygen(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt,
         eflag = cm_get_key(boundparent, pw_ctxt, &key, &keylen);
     } else {
         fprintf(stderr, _("Generating random key; please be patient...\n"));
-        key = (unsigned char*)sec_realloc(NULL, (size_t)keylen);
+        key = (uint8_t*)sec_realloc(NULL, (size_t)keylen);
         eflag = cm_generate_key(key, (size_t)keylen);
         if (eflag != ERR_NOERROR) {
             fprintf(stderr, _("Failed to generate new key\n"));
@@ -1272,16 +1272,16 @@ cmmode_t parse_options(int argc, char *argv[],
         const char *longopt;
         unsigned flags;
         const char **argument;
-        unsigned newmode;
+        cmmode_t newmode;
         unsigned newflags;
     };
     struct cm_option opt_table[] = {
         { 'a', "all",               ALL_USERS | SET_FLAGS,
-                                    NULL, 0, F_ALL_TARGETS },
+                                    NULL, M_UNSET, F_ALL_TARGETS },
         { 'c', "change-password",   ALL_USERS | SET_MODE | SET_FLAGS,
                                     NULL, M_PASSWORD, F_NEEDS_TGT },
         { 'f', "config-fd",         NEEDS_ARG,
-                                    &config_fd_str, 0, 0 },
+                                    &config_fd_str, M_UNSET, 0 },
         { 'g', "generate-key",      NEEDS_ARG | SET_MODE | SET_FLAGS,
                                     mode_params, M_KEYGEN, F_NEEDS_TGT },
         { 'h', "help",              ALL_USERS | SET_MODE,
@@ -1293,7 +1293,7 @@ cmmode_t parse_options(int argc, char *argv[],
         { 'm', "mount",             ALL_USERS | SET_MODE | SET_FLAGS,
                                     NULL, M_MOUNT, F_NEEDS_TGT },
         { 'w', "passwd-fd",         ALL_USERS | NEEDS_ARG,
-                                    &passwd_fd_str, 0, 0 },
+                                    &passwd_fd_str, M_UNSET, 0 },
         { 'p', "prepare",           SET_MODE | SET_FLAGS,
                                     NULL, M_PREPARE, F_NEEDS_TGT },
         { 'r', "release",           SET_MODE | SET_FLAGS,
@@ -1315,23 +1315,24 @@ cmmode_t parse_options(int argc, char *argv[],
         { 'u', "unmount",           ALL_USERS | SET_MODE | SET_FLAGS,
                                     NULL, M_UNMOUNT, F_NEEDS_TGT },
         { 'y', "verify-password",   ALL_USERS | SET_FLAGS,
-                                    NULL, 0, F_VERIFY_PW },  /* FIXME - not implemented? */
+                                    NULL, M_UNSET, F_VERIFY_PW },  /* FIXME - not implemented? */
         { 'v', "version",           ALL_USERS | SET_MODE,
                                     NULL, M_VERSION, 0 },
 #ifdef TESTING
         { 'D', "config-dir",        ALL_USERS | NEEDS_ARG,
-                                    &test_context.argconfigdir, 0, 0 },
+                                    &test_context.argconfigdir, M_UNSET, 0 },
         { 'W', "password",          ALL_USERS | NEEDS_ARG,
-                                    &pw_ctxt->argpasswd[0], 0, 0 },
+                                    &pw_ctxt->argpasswd[0], M_UNSET, 0 },
         { 'N', "newpassword",       ALL_USERS | NEEDS_ARG,
-                                    &pw_ctxt->argpasswd[1], 0, 0 },
+                                    &pw_ctxt->argpasswd[1], M_UNSET, 0 },
         { 'T', "self-test",         ALL_USERS | SET_MODE,
                                     NULL, M_SELFTEST, 0 },
 #endif
-        { '?', NULL, 0, NULL, 0, 0 } };
+        { '?', NULL, 0, NULL, M_UNSET, 0 } };
     const size_t n_options = (sizeof(opt_table) / sizeof(opt_table[0]) - 1);
     char *shortopts, *spos;
-    int i, idx = 0, optchar = '\0';
+    int idx = 0, optchar = '\0';
+    size_t i;
 
     shortopts = (char*)malloc(n_options * 2 + 1);
     spos = shortopts;
@@ -1478,8 +1479,7 @@ int main(int argc, char *argv[])
 
     /* Check & read-in configuration file: */
 #ifndef TESTING
-    if (sycheck_cmtab(cmtab) != ERR_NOERROR
-      || sycheck_directory(CM_MODULE_DIR) != ERR_NOERROR) {
+    if (sycheck_cmtab(cmtab) != ERR_NOERROR) {
         fprintf(stderr, _("Security failure\n"));
         exit(EXIT_INSECURE);
     }
