@@ -33,6 +33,7 @@
 #  if HAVE_STDINT_H
 #    include <stdint.h>
 #  else
+     typedef unsigned short         uint8_t;
      typedef long                   int32_t;
      typedef unsigned long          uint32_t;
      typedef long long              int64_t;
@@ -155,6 +156,7 @@ typedef struct tgtdefn
     char *mountoptions;     /*!< Options passed to 'mount' command */
     char *fsckoptions;      /*!< Options passed to 'fsck' command */
     char *loopdev;          /*!< Loopback device to wrap around raw file */
+    char *supath;           /*!< PATH to setup for commands run as root */
 
     char *cipher;           /*!< Cipher used on filesystem */
     int64_t ivoffset;       /*!< Cipher initialization-vector offset */
