@@ -50,13 +50,17 @@
 
 
 static const char *ETCMTAB = "/etc/mtab",
-                  *ETCMTABTMP = "/etc/mtab.cm";
+                  *ETCMTABTMP = "/etc/mtab.cm",
+                  *STDPATH = CM_DEFAULT_SUPATH;
 
 
 enum {
-    F_MATCHUID = 0x01, F_CLOSE1 = 0x02 };
+    F_MATCHUID =  0x01,     /*!< Set real UID to match effective UID */
+    F_CLOSE1 =    0x02,     /*!< Close stdout on child process */
+    F_SETPATH =   0x04      /*!< Set standard PATH for child process */
+};
 static int run_sucommand(const char *path, const char *argv[],
-                        unsigned switches);
+                        const char *supath, unsigned switches);
 int do_addmntent(const tgtdefn_t *tgt);
 int do_rmvmntent(const tgtdefn_t *tgt);
 
@@ -185,7 +189,7 @@ int fs_mount(const char *dev, const tgtdefn_t *tgt)
     argv[idx++] = dev; argv[idx++] = tgt->dir;
     argv[idx++] = NULL;
 
-    stat = run_sucommand(DLGT_MOUNT, argv, F_MATCHUID);
+    stat = run_sucommand(DLGT_MOUNT, argv, tgt->supath, F_MATCHUID);
     eflag = (stat != 0 ? ERR_BADMOUNT: ERR_NOERROR);
 
     return eflag;
@@ -237,7 +241,7 @@ int fs_unmount(const tgtdefn_t *tgt)
     argv[idx++] = tgt->dir;
     argv[idx++] = NULL;
 
-    stat = run_sucommand(DLGT_UMOUNT, argv, F_MATCHUID);
+    stat = run_sucommand(DLGT_UMOUNT, argv, tgt->supath, F_MATCHUID);
     eflag = (stat != 0 ? ERR_BADMOUNT: ERR_NOERROR);
 
     return eflag;
@@ -282,7 +286,8 @@ int fs_swapon(const char *mntdev, const tgtdefn_t *tgt)
             argv[idx++] = mntdev;
             argv[idx++] = NULL;
 
-            stat = run_sucommand(DLGT_MKSWAP, argv, F_CLOSE1);
+            stat = run_sucommand(DLGT_MKSWAP, argv,
+                                 tgt->supath, F_CLOSE1);
             eflag = (stat != 0 ? ERR_BADSWAP : ERR_NOERROR);
             if (eflag != ERR_NOERROR) goto bail_out;
         } else {
@@ -336,7 +341,7 @@ int fs_swapoff(const tgtdefn_t *tgt)
 
 int do_addmntent(const tgtdefn_t *tgt)
     /*! Add entry into /etc/mtab for newly-mounted filing system */
-{   char *mntdev=NULL;
+{   char *mntdev = NULL;
     struct mntent mntinfo;
     FILE *fp;
     int eflag=ERR_NOERROR;
@@ -506,7 +511,8 @@ int fs_check(const char *dev, const tgtdefn_t *tgt)
     argv[idx++] = dev;
     argv[idx++] = NULL;
 
-    stat = run_sucommand(DLGT_FSCK, argv, F_MATCHUID);
+    stat = run_sucommand(DLGT_FSCK, argv,
+                         tgt->supath, F_MATCHUID | F_SETPATH);
     eflag = ((stat == 0 || stat == 1) ? ERR_NOERROR : ERR_BADFSCK);
 
     if (opts != NULL) {
@@ -524,7 +530,7 @@ int fs_check(const char *dev, const tgtdefn_t *tgt)
 double fs_entropy(const char *dev, const size_t blklen)
     /*! Calculate degree of randomness on initial block of filesystem */
 {   unsigned *counts = NULL;
-    unsigned char buff[4096];
+    uint8_t buff[4096];
     size_t chunk, totcount = 0;
     int fd, step, i;
     double plogp = 0.0;
@@ -566,8 +572,8 @@ double fs_entropy(const char *dev, const size_t blklen)
 #if !ERSATZ_MOUNT || !ERSATZ_UMOUNT || WITH_FSCK || WITH_CSWAP
 
 static int run_sucommand(const char *path, const char **argv,
-                        unsigned switches)
-    /*! fork (& wait for) system-command as root */
+                         const char *supath, unsigned switches)
+    /*! Fork (& wait for) system-command as root */
 {   pid_t child;
     int stat=-1, fd;
 
@@ -587,6 +593,12 @@ static int run_sucommand(const char *path, const char **argv,
                 if (fd >= 0) (void)dup2(fd, STDOUT_FILENO);
                 else (void)close(STDOUT_FILENO);
             }
+            if ((switches & F_SETPATH) != 0) {
+                if (supath == NULL) supath = STDPATH;
+                if (setenv("PATH", supath, 1) != 0) {
+                  exit(EXIT_BADEXEC);
+                }
+            }
 
             execv(path, (char *const *)argv);
             fprintf(stderr, "failed to invoke \"%s\"\n", path);
