@@ -51,7 +51,7 @@
  *  covering legacy /dev/loop/0 style
  *  as well as current /dev/loop0 style.
  */
-static char *loop_formats[] = {
+static const char *loop_formats[] = {
     "/dev/loop%u", "/dev/loop/%u", NULL };
 
 
