@@ -86,22 +86,22 @@ typedef struct {
 static tgt_option_t
     /** Menu of options within 'flags' field of target definition */
     setup_options[] = {
-        { "defaults",   0U,             FLG_DEFAULTS },
-        { "user",       ~0U,            FLG_USER },
-        { "nouser",     ~FLG_USER,      0U },
-        { "fsck",       ~0U,            FLG_FSCK },
-        { "nofsck",     ~FLG_FSCK,      0U },
-        { "mkswap",     ~0U,            FLG_MKSWAP },
-        { "nomkswap",   ~FLG_MKSWAP,    0U },
-        { "trim",       ~0U,            FLG_TRIM },
-        { "notrim",     ~FLG_TRIM,      0U },
+        { "defaults",   0U,                 FLG_DEFAULTS },
+        { "user",       ~0U,                FLG_USER },
+        { "nouser",     ~0U ^ FLG_USER,     0U },
+        { "fsck",       ~0U,                FLG_FSCK },
+        { "nofsck",     ~0U ^ FLG_FSCK,     0U },
+        { "mkswap",     ~0U,                FLG_MKSWAP },
+        { "nomkswap",   ~0U ^ FLG_MKSWAP,   0U },
+        { "trim",       ~0U,                FLG_TRIM },
+        { "notrim",     ~0U ^ FLG_TRIM,     0U },
         { NULL, ~0U, 0U } },
     /** Menu of options within 'bootaction' field of target definition */
     boot_options[] = {
-        { "none",       ~FLG_BOOT_MASK,     0 },
-        { "mount",      ~FLG_BOOT_MASK,     FLG_BOOT_MOUNT },
-        { "swap",       ~FLG_BOOT_MASK,     FLG_BOOT_SWAP },
-        { "prepare",    ~FLG_BOOT_MASK,     FLG_BOOT_PREP },
+        { "none",       ~0U ^ FLG_BOOT_MASK,    0 },
+        { "mount",      ~0U ^ FLG_BOOT_MASK,    FLG_BOOT_MOUNT },
+        { "swap",       ~0U ^ FLG_BOOT_MASK,    FLG_BOOT_SWAP },
+        { "prepare",    ~0U ^ FLG_BOOT_MASK,    FLG_BOOT_PREP },
         { NULL, ~0U, 0U }
     };
 
@@ -118,7 +118,7 @@ static struct vardefn *vardefns = NULL;
 static tgtdefn_t *parse_stream(FILE *fp, const char *cfgname);
 
 
-void set_variable(char *varname, char *value)
+void set_variable(const char *varname, const char *value)
     /** Set the value of an environmental variable */
 {   struct vardefn *newvar;
 
@@ -203,6 +203,7 @@ tgtdefn_t *alloc_tgtdefn(const tgtdefn_t *prototype)
     tgt->mountoptions = DFLT_OR_PROTO(NULL, cm_strdup(prototype->mountoptions));
     tgt->fsckoptions = DFLT_OR_PROTO(NULL, cm_strdup(prototype->fsckoptions));
     tgt->loopdev = NULL;
+    tgt->supath = DFLT_OR_PROTO(NULL, cm_strdup(prototype->supath));
 
     tgt->cipher = DFLT_OR_PROTO(cm_strdup(CM_DEFAULT_CIPHER),
                                 cm_strdup(prototype->cipher));
@@ -256,6 +257,7 @@ tgtdefn_t *clone_tgtdefn(const tgtdefn_t *orig)
     clone->mountoptions = cm_strdup(orig->mountoptions);
     clone->fsckoptions = cm_strdup(orig->fsckoptions);
     clone->loopdev = cm_strdup(orig->loopdev);
+    clone->supath = cm_strdup(orig->supath);
 
     clone->cipher = cm_strdup(orig->cipher);
     clone->ivoffset = orig->ivoffset;
@@ -276,21 +278,22 @@ tgtdefn_t *clone_tgtdefn(const tgtdefn_t *orig)
 void free_tgtdefn(tgtdefn_t *tgt)
     /** Relinquish storage for a target-structure */
 {
-    if (tgt->ident != NULL) free((void*)tgt->ident);
+    free((void*)tgt->ident);
 
-    if (tgt->dev != NULL) free((void*)tgt->dev);
-    if (tgt->dir != NULL) free((void*)tgt->dir);
-    if (tgt->fstype != NULL) free((void*)tgt->fstype);
-    if (tgt->mountoptions != NULL) free((void*)tgt->mountoptions);
-    if (tgt->fsckoptions != NULL) free((void*)tgt->fsckoptions);
-    if (tgt->loopdev != NULL) free((void*)tgt->loopdev);
+    free((void*)tgt->dev);
+    free((void*)tgt->dir);
+    free((void*)tgt->fstype);
+    free((void*)tgt->mountoptions);
+    free((void*)tgt->fsckoptions);
+    free((void*)tgt->loopdev);
+    free((void*)tgt->supath);
 
-    if (tgt->cipher != NULL) free((void*)tgt->cipher);
+    free((void*)tgt->cipher);
 
-    if (tgt->key.format != NULL) free((void*)tgt->key.format);
-    if (tgt->key.filename != NULL) free((void*)tgt->key.filename);
-    if (tgt->key.digestalg != NULL) free((void*)tgt->key.digestalg);
-    if (tgt->key.cipheralg != NULL) free((void*)tgt->key.cipheralg);
+    free((void*)tgt->key.format);
+    free((void*)tgt->key.filename);
+    free((void*)tgt->key.digestalg);
+    free((void*)tgt->key.cipheralg);
 
     free((void*)tgt);
 }
@@ -316,7 +319,7 @@ void expand_variables(char **buff, const char *src)
 {   const size_t srclen = strlen(src);
     enum { S_PLAIN, S_VAR };
     const char *curs = src;
-    char *varname, *varp;
+    char *varname, *varp = NULL;
     int literal = 0;
     unsigned state;
     cm_string_t *result;
@@ -494,6 +497,8 @@ static void read_token(char *buff, unsigned *t_state, tgtdefn_t *tgt)
                             proc_string,    NULL },
         { "loop",           OFFSET(loopdev),
                             proc_string,    NULL },
+        { "supath",         OFFSET(supath),
+                            proc_string,    NULL },
         { "cipher",         OFFSET(cipher),
                             proc_string,    NULL },
         { "ivoffset",       OFFSET(ivoffset),
