@@ -44,7 +44,7 @@
 #endif
 
 
-cm_string_t *cm_str_init(char *val)
+cm_string_t *cm_str_init(const char *val)
     /** Construct a new string object from a plain char* string */
 {   cm_string_t *str;
 
@@ -333,7 +333,7 @@ void *sec_realloc(void *ptr, size_t size)
 }
 
 
-void mem_cleanse(unsigned char *addr, size_t sz)
+void mem_cleanse(uint8_t *addr, size_t sz)
     /** Overwrite memory with (weak) pseudo-random numbers */
 {   size_t i;
     static unsigned long salt=0x917c;
@@ -356,7 +356,7 @@ void sec_free(void *ptr)
     memarr = ((size_t*)ptr) - 1;
     sz = memarr[0];
 
-    mem_cleanse((unsigned char*)(memarr + 1), sz);
+    mem_cleanse((uint8_t*)(memarr + 1), sz);
 
     free((void*)memarr);
 }
@@ -367,18 +367,18 @@ void sec_free(void *ptr)
  *  using a cryptographic-quality iterative message-digest
  *  applied to various entropy sources including /dev/random.
  */
-int cm_generate_key(unsigned char *buff, size_t len)
+int cm_generate_key(uint8_t *buff, size_t len)
 {   struct rnddev {
         const char *name;
-        short devmaj;
-        short devmin; } *rndsrc;
+        unsigned short devmaj;
+        unsigned short devmin; } *rndsrc;
     struct rnddev devs[] = {
         { "/dev/urandom",   MEM_MAJOR,      9 },
         { "/dev/random",    MEM_MAJOR,      8 },
         { "/dev/hwrng",     MISC_MAJOR,   183 },
         { NULL, 0, 0 } };
     const size_t POOL_SIZE = 256, NOISE_CHUNK = 16;
-    unsigned char *mdval, *pool, *devbuff = NULL;
+    uint8_t *mdval, *pool, *devbuff = NULL;
     size_t pos, step, mdlen;
     const pid_t pid = getpid();
     struct tms tbuff;
@@ -386,9 +386,9 @@ int cm_generate_key(unsigned char *buff, size_t len)
     static unsigned seed = 1993;
     int first = 1, total_entropy = 0, eflag = ERR_NOERROR;
 
-    pool = (unsigned char*)sec_realloc(NULL, POOL_SIZE);
+    pool = (uint8_t*)sec_realloc(NULL, POOL_SIZE);
 
-    devbuff = (unsigned char*)sec_realloc(NULL, NOISE_CHUNK);
+    devbuff = (uint8_t*)sec_realloc(NULL, NOISE_CHUNK);
     for (rndsrc=devs; rndsrc->name!=NULL; ++rndsrc) {
         struct stat sbuff;
         ssize_t nread;
@@ -431,11 +431,11 @@ int cm_generate_key(unsigned char *buff, size_t len)
         /* Fold-in various sources of entropy: */
         cm_sha1_block(mdcontext, pool, POOL_SIZE);
 
-        cm_sha1_block(mdcontext, (unsigned char*)&pid, sizeof(pid));
+        cm_sha1_block(mdcontext, (uint8_t*)&pid, sizeof(pid));
         clk = times(&tbuff);
-        cm_sha1_block(mdcontext, (unsigned char*)&clk, sizeof(clk));
-        cm_sha1_block(mdcontext, (unsigned char*)&seed, sizeof(seed));
-        cm_sha1_block(mdcontext, (unsigned char*)&tbuff, sizeof(tbuff));
+        cm_sha1_block(mdcontext, (uint8_t*)&clk, sizeof(clk));
+        cm_sha1_block(mdcontext, (uint8_t*)&seed, sizeof(seed));
+        cm_sha1_block(mdcontext, (uint8_t*)&tbuff, sizeof(tbuff));
 
         cm_sha1_final(mdcontext, &mdval, &mdlen);
 
@@ -484,9 +484,9 @@ ssize_t cm_ttygetpasswd(const char *prompt, char **buff)
         pwlen = strlen(tmppass);
         if (pwlen > 0 && tmppass[pwlen-1] == '\n') {
             tmppass[--pwlen] = '\0'; }
-        *buff = sec_realloc((void*)*buff, (size_t)(pwlen+1));
+        *buff = (char*)sec_realloc((void*)*buff, (size_t)(pwlen+1));
         strcpy(*buff, tmppass);
-        mem_cleanse((unsigned char*)tmppass, sizeof(tmppass));
+        mem_cleanse((uint8_t*)tmppass, sizeof(tmppass));
         tcsetattr(fileno(stdin), TCSAFLUSH, &oldttystate);
         printf("\n");
     } else {
@@ -498,7 +498,7 @@ ssize_t cm_ttygetpasswd(const char *prompt, char **buff)
     pwlen = strlen(tmppass);
     *buff = sec_realloc((void*)*buff, (size_t)(pwlen+1));
     strcpy(*buff, tmppass);
-    mem_cleanse((unsigned char*)tmppass, (size_t)(pwlen+1));
+    mem_cleanse((uint8_t*)tmppass, (size_t)(pwlen+1));
 #endif  /* !HAVE_TERMIOS */
 
     return pwlen;
@@ -599,15 +599,15 @@ unsigned km_aug_keysz(unsigned keylen, unsigned blksz)
 }
 
 
-unsigned char *km_aug_key(const unsigned char *key, unsigned keylen,
+uint8_t *km_aug_key(const uint8_t *key, unsigned keylen,
                     unsigned blocksz, size_t *buffsz)
     /* Augment cipher key with checksum prior to encryption & storage */
-{   unsigned char *buff=NULL;
+{   uint8_t *buff=NULL;
     uint32_t chksum, *kptr=NULL;
     size_t idx, cnt;
 
     *buffsz = km_aug_keysz(keylen, blocksz);
-    buff = (unsigned char*)sec_realloc(buff, *buffsz);
+    buff = (uint8_t*)sec_realloc(buff, *buffsz);
 
     /* Copy key into zero-padded buffer: */
     memset(buff, 0, (size_t)*buffsz);
@@ -633,7 +633,7 @@ unsigned char *km_aug_key(const unsigned char *key, unsigned keylen,
 }
 
 
-int km_aug_verify(const unsigned char *buff, unsigned keylen,
+int km_aug_verify(const uint8_t *buff, unsigned keylen,
                 uint32_t *expected, uint32_t *actual)
     /* Check augmented cipher key against simple checksum */
 {   unsigned cnt;
@@ -689,7 +689,7 @@ cm_sha1_ctxt_t *cm_sha1_init(void)
 }
 
 
-void cm_sha1_block(cm_sha1_ctxt_t *ctxt, const unsigned char *buff, size_t len)
+void cm_sha1_block(cm_sha1_ctxt_t *ctxt, const uint8_t *buff, size_t len)
 {   uint32_t W[80], A, B, C, D, E, q;
     unsigned idx, round;
 
@@ -753,8 +753,8 @@ void cm_sha1_block(cm_sha1_ctxt_t *ctxt, const unsigned char *buff, size_t len)
 }
 
 
-void cm_sha1_final(cm_sha1_ctxt_t *ctxt, unsigned char **mdval, size_t *mdlen)
-{   unsigned char *cptr, buff[64], mrk=0x80;
+void cm_sha1_final(cm_sha1_ctxt_t *ctxt, uint8_t **mdval, size_t *mdlen)
+{   uint8_t *cptr, buff[64], mrk=0x80;
     unsigned idx, padlen;
     uint32_t msglen;
 
@@ -771,14 +771,14 @@ void cm_sha1_final(cm_sha1_ctxt_t *ctxt, unsigned char **mdval, size_t *mdlen)
     cm_sha1_block(ctxt, buff, (size_t)8);
 
     /* Transcribe internal state into array of bytes: */
-    *mdval = (unsigned char*)sec_realloc(NULL, (size_t)CM_SHA1_SIZE);
+    *mdval = (uint8_t*)sec_realloc(NULL, (size_t)CM_SHA1_SIZE);
     *mdlen = CM_SHA1_SIZE;
     cptr = *mdval;
     for (idx=0; idx<5; ++idx) {
-        cptr[0] = (unsigned char)((ctxt->H[idx] >> 24) & 0xff);
-        cptr[1] = (unsigned char)((ctxt->H[idx] >> 16) & 0xff);
-        cptr[2] = (unsigned char)((ctxt->H[idx] >> 8) & 0xff);
-        cptr[3] = (unsigned char)(ctxt->H[idx] & 0xff);
+        cptr[0] = (uint8_t)((ctxt->H[idx] >> 24) & 0xff);
+        cptr[1] = (uint8_t)((ctxt->H[idx] >> 16) & 0xff);
+        cptr[2] = (uint8_t)((ctxt->H[idx] >> 8) & 0xff);
+        cptr[3] = (uint8_t)(ctxt->H[idx] & 0xff);
         cptr += 4;
     }
 }
@@ -798,11 +798,11 @@ void cm_sha1_free(cm_sha1_ctxt_t *ctxt)
 int ut_test_sha1()
     /* Check internal SHA1 hashing algorithm against known test-vectors */
 {   cm_sha1_ctxt_t *ctxt;
-    unsigned char *mdval;
+    uint8_t *mdval;
     unsigned b, q, idx;
     size_t mdlen;
     struct {
-        char *input, *hash; } cases[] = {
+        const char *input, *hash; } cases[] = {
     { "",                       "da39a3ee5e6b4b0d3255bfef95601890afd80709" },
     { "a",                      "86f7e437faa5a7fce15d1ddcb9eaeaea377667b8" },
     { "alpha",                  "be76331b95dfc399cd776d2fc68021e0db03cc4f" },
@@ -817,7 +817,7 @@ int ut_test_sha1()
     idx = 0;
     while (cases[idx].input != NULL) {
         ctxt = cm_sha1_init();
-        cm_sha1_block(ctxt, (const unsigned char*)cases[idx].input,
+        cm_sha1_block(ctxt, (const uint8_t*)cases[idx].input,
                             strlen(cases[idx].input));
         cm_sha1_final(ctxt, &mdval, &mdlen);
         cm_sha1_free(ctxt);
@@ -841,14 +841,15 @@ int ut_test_sha1()
 
 
 void cm_pwd_fortify(const char *passwd, unsigned iterations,
-                const unsigned char *salt, size_t saltlen,
-                unsigned char **key, size_t keylen)
+                const uint8_t *salt, size_t saltlen,
+                uint8_t **key, size_t keylen)
     /* Iteratively apply hashing algorithm to stretch & fortify password */
-{   cm_sha1_ctxt_t *mdcontext=NULL;
-    unsigned char q, *permsalt=NULL, *mdval=NULL, *mdval_prev=NULL;
+{   cm_sha1_ctxt_t *mdcontext = NULL;
+    uint8_t q, *permsalt = NULL, *mdval = NULL, *mdval_prev = NULL;
     size_t idx, pos, mdlen, pwlen, sz=0, newidx;
     uint32_t cnt, r_val;
-    const uint32_t r_mult=421, r_inc=54773, r_mod=259200, r_scale=69317;
+    const uint32_t r_mult = 421, r_inc = 54773,
+                   r_mod = 259200, r_scale = 69317;
 
     /* Initialize random-number seed from password vector: */
     pwlen = strlen(passwd);
@@ -859,15 +860,15 @@ void cm_pwd_fortify(const char *passwd, unsigned iterations,
 
     /* Assemble salt-vector which can be randomly permuted: */
     if (salt != NULL && saltlen > 0) {
-        permsalt = sec_realloc((void*)permsalt, saltlen);
+        permsalt = (uint8_t*)sec_realloc((void*)permsalt, saltlen);
         memcpy((void*)permsalt, (const void*)salt, saltlen);
     } else {
         if (saltlen == 0) saltlen = 16;
-        permsalt = sec_realloc((void*)permsalt, saltlen);
+        permsalt = (uint8_t*)sec_realloc((void*)permsalt, saltlen);
         for (idx=0; idx<saltlen; ++idx) permsalt[idx] = idx;
     }
 
-    *key = (unsigned char*)sec_realloc((void*)*key, keylen);
+    *key = (uint8_t*)sec_realloc((void*)*key, keylen);
     pos = 0;
     while (pos < keylen) {
         /* Iteratively apply hashing function to fortify password: */
@@ -899,7 +900,7 @@ void cm_pwd_fortify(const char *passwd, unsigned iterations,
             }
 
             /* Mix-in password: */
-            cm_sha1_block(mdcontext, (const unsigned char*)passwd, pwlen);
+            cm_sha1_block(mdcontext, (const uint8_t*)passwd, pwlen);
 
             cm_sha1_final(mdcontext, &mdval, &mdlen);
 
@@ -937,12 +938,12 @@ int ut_pwfort()
 {   unsigned idx, pos, r=0;
     struct fwdbck {
         char *passwd;
-        unsigned char *fwd, *bck;
+        uint8_t *fwd, *bck;
     } *fbs;
     struct tcase {
         const char *passwd;
         const char *salt;
-        unsigned char front[4], back[4];
+        uint8_t front[4], back[4];
     } tcases[] = {
         { "Mary", "alpha",      { 0x46, 0x94, 0x0f, 0xb1 },
                                 { 0x8e, 0x0c, 0x6a, 0x6b } },
@@ -956,7 +957,7 @@ int ut_pwfort()
                                 { 0xf6, 0xaa, 0x02, 0x5d } },
         { NULL, NULL,           {},
                                 {} } };
-    unsigned char *key=NULL;
+    uint8_t *key=NULL;
     const unsigned n_fbs = 64, n_its = 32;
     const size_t pwlen = 13, saltlen = 17, keylen = 1024;
 
@@ -1007,7 +1008,7 @@ int ut_pwfort()
     /* Check known test cases: */
     for (idx=0; tcases[idx].passwd!=NULL; ++idx) {
         cm_pwd_fortify(tcases[idx].passwd, n_its,
-                    (unsigned char*)tcases[idx].salt, strlen(tcases[idx].salt),
+                    (uint8_t*)tcases[idx].salt, strlen(tcases[idx].salt),
                     &key, keylen);
 #if 0
         fprintf(stderr, "%s: ", tcases[idx].passwd);
