@@ -57,7 +57,7 @@ typedef struct cm_string {
 typedef enum {
     CM_SYSCONF_PFX, CM_SYSRUN_PFX } cm_path_prefix_t;
 
-cm_string_t *cm_str_init(char *val);
+cm_string_t *cm_str_init(const char *val);
 cm_string_t *cm_str_alloc(size_t bufflen);
 cm_string_t *cm_str_realloc(cm_string_t *str, size_t bufflen);
 cm_string_t *cm_str_append(cm_string_t *str, const cm_string_t *addend);
@@ -72,17 +72,17 @@ int cm_strcasecmp(const char *s1, const char *s2);
 int cm_startswith(const char **str, const char *prefix);
 
 void *sec_realloc(void *ptr, size_t size);
-void mem_cleanse(unsigned char *addr, size_t sz);
+void mem_cleanse(uint8_t *addr, size_t sz);
 void sec_free(void *ptr);
 
-int cm_generate_key(unsigned char *key, size_t len);
+int cm_generate_key(uint8_t *key, size_t len);
 int km_get_passwd(const char *ident, const km_pw_context_t *pw_ctxt,
                 char **passwd, int isnew, int verify);
 int cm_confirm(const char *msg);
 unsigned km_aug_keysz(unsigned keylen, unsigned blksz);
-unsigned char *km_aug_key(const unsigned char *key, unsigned keylen,
+uint8_t *km_aug_key(const uint8_t *key, unsigned keylen,
                 unsigned blocksz, size_t *buffsz);
-int km_aug_verify(const unsigned char *buff, unsigned keylen,
+int km_aug_verify(const uint8_t *buff, unsigned keylen,
                 uint32_t *expected, uint32_t *actual);
 
 enum { CM_SHA1_SIZE = 20 };
@@ -94,26 +94,26 @@ typedef struct cm_sha1_ctxt {
 } cm_sha1_ctxt_t;
 
 cm_sha1_ctxt_t *cm_sha1_init(void);
-void cm_sha1_block(cm_sha1_ctxt_t *ctxt, const unsigned char *buff, size_t len);
-void cm_sha1_final(cm_sha1_ctxt_t *ctxt, unsigned char **mdval, size_t *mdlen);
+void cm_sha1_block(cm_sha1_ctxt_t *ctxt, const uint8_t *buff, size_t len);
+void cm_sha1_final(cm_sha1_ctxt_t *ctxt, uint8_t **mdval, size_t *mdlen);
 void cm_sha1_free(cm_sha1_ctxt_t *ctxt);
 
 void cm_pwd_fortify(const char *passwd, unsigned iterations,
-                const unsigned char *salt, size_t saltlen,
-                unsigned char **key, size_t keylen);
+                const uint8_t *salt, size_t saltlen,
+                uint8_t **key, size_t keylen);
 
 
-static inline uint16_t pack_uint16(const unsigned char *buff) {
+static inline uint16_t pack_uint16(const uint8_t *buff) {
     return (((uint16_t)buff[1]) << 8) | ((uint16_t)buff[0]); }
 
-static inline void unpack_uint16(unsigned char *buff, const uint16_t val) {
+static inline void unpack_uint16(uint8_t *buff, const uint16_t val) {
     buff[0] = (val & 0x00ff); buff[1] = (val & 0xff00) >> 8; }
 
-static inline uint32_t pack_uint32(const unsigned char *buff) {
+static inline uint32_t pack_uint32(const uint8_t *buff) {
     return (((uint32_t)buff[3]) << 24) | (((uint32_t)buff[2]) << 16) \
             | (((uint32_t)buff[1]) << 8) | ((uint32_t)buff[0]); }
 
-static inline void unpack_uint32(unsigned char *buff, const uint32_t val) {
+static inline void unpack_uint32(uint8_t *buff, const uint32_t val) {
     buff[0] = (val & 0x000000ff); buff[1] = (val & 0x0000ff00) >> 8;
     buff[2] = (val & 0x00ff0000) >> 16; buff[3] = (val & 0xff000000) >> 24; }
 
